@@ -1,6 +1,7 @@
 package ZMQ::FFI;
-$ZMQ::FFI::VERSION = '1.05_02';
-# ABSTRACT: version agnostic Perl bindings for zeromq using ffi
+$ZMQ::FFI::VERSION = '1.16_01'; # TRIAL
+
+$ZMQ::FFI::VERSION = '1.1601';# ABSTRACT: version agnostic Perl bindings for zeromq using ffi
 
 use strict;
 use warnings;
@@ -8,6 +9,15 @@ use warnings;
 use ZMQ::FFI::Util qw(zmq_soname zmq_version valid_soname);
 use Carp;
 
+use Import::Into;
+
+sub import {
+    my ($pkg, @import_args) = @_;
+
+    my $target = caller;
+    ZMQ::FFI::Constants->import::into($target, @import_args);
+}
+
 sub new {
     my ($self, %args) = @_;
 
@@ -20,17 +30,27 @@ sub new {
         $args{soname} = zmq_soname( die => 1 );
     }
 
-    my ($major) = zmq_version($args{soname});
+    my ($major, $minor) = zmq_version($args{soname});
 
     if ($major == 2) {
         require ZMQ::FFI::ZMQ2::Context;
         return ZMQ::FFI::ZMQ2::Context->new(%args);
     }
-    else {
+    elsif ($major == 3) {
         require ZMQ::FFI::ZMQ3::Context;
         return ZMQ::FFI::ZMQ3::Context->new(%args);
+    } 
+    else {
+	if ($major == 4 and $minor == 0) {
+            require ZMQ::FFI::ZMQ4::Context;
+            return ZMQ::FFI::ZMQ4::Context->new(%args);
+        }
+        else {
+            require ZMQ::FFI::ZMQ4_1::Context;
+            return ZMQ::FFI::ZMQ4_1::Context->new(%args);
+        }
     }
-};
+}
 
 1;
 
@@ -46,15 +66,14 @@ ZMQ::FFI - version agnostic Perl bindings for zeromq using ffi
 
 =head1 VERSION
 
-version 1.05_02
+version 1.16_01
 
 =head1 SYNOPSIS
 
     #### send/recv ####
 
     use v5.10;
-    use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_REQ ZMQ_REP);
+    use ZMQ::FFI qw(ZMQ_REQ ZMQ_REP);
 
     my $endpoint = "ipc://zmq-ffi-$$";
     my $ctx      = ZMQ::FFI->new();
@@ -74,8 +93,7 @@ version 1.05_02
     #### pub/sub ####
 
     use v5.10;
-    use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_PUB ZMQ_SUB);
+    use ZMQ::FFI qw(ZMQ_PUB ZMQ_SUB);
     use Time::HiRes q(usleep);
 
     my $endpoint = "ipc://zmq-ffi-$$";
@@ -125,8 +143,7 @@ version 1.05_02
     #### multipart ####
 
     use v5.10;
-    use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_DEALER ZMQ_ROUTER);
+    use ZMQ::FFI qw(ZMQ_DEALER ZMQ_ROUTER);
 
     my $endpoint = "ipc://zmq-ffi-$$";
     my $ctx      = ZMQ::FFI->new();
@@ -148,8 +165,7 @@ version 1.05_02
     #### nonblocking ####
 
     use v5.10;
-    use ZMQ::FFI;
-    use ZMQ::FFI::Constants qw(ZMQ_PUSH ZMQ_PULL);
+    use ZMQ::FFI qw(ZMQ_PUSH ZMQ_PULL);
     use AnyEvent;
     use EV;
 
@@ -379,17 +395,23 @@ get the file descriptor associated with the socket
 
 =head2 get
 
+    my $option_value = $socket->get($option_name, $option_type);
+
     my $linger = $socket->get(ZMQ_LINGER, 'int');
 
-return the value for the specified socket option. C<$option_type> is the type
-associated with the option value in the zeromq API (C<zmq_getsockopt> man page)
+generic method to get the value for any socket option. C<$option_type> is the
+type associated with C<$option_value> in the zeromq API (C<zmq_getsockopt> man
+page)
 
 =head2 set
 
+    $socket->set($option_name, $option_type, $option_value);
+
     $socket->set(ZMQ_IDENTITY, 'binary', 'foo');
 
-set the socket option to the specified value. C<$option_type> is the type
-associated with the option value in the zeromq API (C<zmq_setsockopt> man page)
+generic method to set the value for any socket option.  C<$option_type> is the
+type associated with C<$option_value> in the zeromq API (C<zmq_setsockopt> man
+page)
 
 =head2 subscribe
 
@@ -634,7 +656,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
