@@ -1,6 +1,7 @@
 package ZMQ::FFI::ErrorHelper;
-$ZMQ::FFI::ErrorHelper::VERSION = '1.05_02';
-use Carp;
+$ZMQ::FFI::ErrorHelper::VERSION = '1.16_01'; # TRIAL
+
+$ZMQ::FFI::ErrorHelper::VERSION = '1.1601';use Carp;
 use FFI::Platypus;
 use ZMQ::FFI::Util qw(zmq_version);
 
@@ -110,7 +111,7 @@ ZMQ::FFI::ErrorHelper
 
 =head1 VERSION
 
-version 1.05_02
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -118,7 +119,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
