@@ -1,9 +1,11 @@
 package ZMQ::FFI::SocketRole;
-$ZMQ::FFI::SocketRole::VERSION = '1.05_02';
-use FFI::Platypus;
+$ZMQ::FFI::SocketRole::VERSION = '1.16_01'; # TRIAL
+
+$ZMQ::FFI::SocketRole::VERSION = '1.1601';use FFI::Platypus;
 use FFI::Platypus::Memory qw(malloc);
 
 use ZMQ::FFI::Constants qw(zmq_msg_t_size);
+use ZMQ::FFI::Util qw(current_tid);
 
 use Moo::Role;
 
@@ -12,13 +14,6 @@ has soname => (
     required => 1,
 );
 
-# context to associate socket instance with.
-# reference necessary to guard against premature object destruction
-has ctx => (
-    is       => 'ro',
-    required => 1,
-);
-
 # zmq constant socket type, e.g. ZMQ_REQ
 has type => (
     is       => 'ro',
@@ -26,11 +21,18 @@ has type => (
 );
 
 # real underlying zmq socket pointer
-has _socket => (
+has socket_ptr => (
     is      => 'rw',
     default => -1,
 );
 
+# a weak reference to the context object
+has context => (
+    is       => 'ro',
+    required => 1,
+    weak_ref => 1,
+);
+
 # message struct to reuse when sending/receiving
 has _zmq_msg_t => (
     is        => 'ro',
@@ -44,6 +46,12 @@ has _pid => (
     default => sub { $$ },
 );
 
+# used to make sure we handle thread situations correctly
+has _tid => (
+    is      => 'ro',
+    default => sub { current_tid() },
+);
+
 has sockopt_sizes => (
     is      => 'ro',
     lazy    => 1,
@@ -111,7 +119,7 @@ ZMQ::FFI::SocketRole
 
 =head1 VERSION
 
-version 1.05_02
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -119,7 +127,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
