@@ -1,6 +1,7 @@
 package ZMQ::FFI::Util;
-$ZMQ::FFI::Util::VERSION = '1.05_02';
-# ABSTRACT: zmq convenience functions
+$ZMQ::FFI::Util::VERSION = '1.16_01'; # TRIAL
+
+$ZMQ::FFI::Util::VERSION = '1.1601';# ABSTRACT: zmq convenience functions
 
 use strict;
 use warnings;
@@ -13,6 +14,7 @@ use Sub::Exporter -setup => {
         zmq_soname
         zmq_version
         valid_soname
+        current_tid
     )],
 };
 
@@ -31,7 +33,7 @@ sub zmq_soname {
     # If Linux extensions fail also try platform specific
     # extensions (e.g. OS X) before giving up.
     my @sonames = qw(
-        libzmq.so    libzmq.so.4    libzmq.so.3    libzmq.so.1
+        libzmq.so    libzmq.so.5    libzmq.so.4    libzmq.so.3    libzmq.so.1
         libzmq.dylib libzmq.4.dylib libzmq.3.dylib libzmq.1.dylib
     );
 
@@ -97,6 +99,17 @@ sub valid_soname {
     return defined $zmq_version;
 }
 
+sub current_tid {
+    if (eval 'use threads; 1') {
+        require threads;
+        threads->import();
+        return threads->tid;
+    }
+    else {
+        return -1;
+    }
+}
+
 1;
 
 __END__
@@ -111,7 +124,7 @@ ZMQ::FFI::Util - zmq convenience functions
 
 =head1 VERSION
 
-version 1.05_02
+version 1.16_01
 
 =head1 SYNOPSIS
 
@@ -127,6 +140,7 @@ version 1.05_02
 Tries to load the following sonames (in order):
 
     libzmq.so
+    libzmq.so.5
     libzmq.so.4
     libzmq.so.3
     libzmq.so.1
@@ -162,7 +176,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
