@@ -1,6 +1,7 @@
 package ZMQ::FFI::Versioner;
-$ZMQ::FFI::Versioner::VERSION = '1.05_02';
-use Moo::Role;
+$ZMQ::FFI::Versioner::VERSION = '1.16_01'; # TRIAL
+
+$ZMQ::FFI::Versioner::VERSION = '1.1601';use Moo::Role;
 
 use ZMQ::FFI::Util qw(zmq_version);
 
@@ -34,7 +35,7 @@ ZMQ::FFI::Versioner
 
 =head1 VERSION
 
-version 1.05_02
+version 1.16_01
 
 =head1 AUTHOR
 
@@ -42,7 +43,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dylan Cali.
+This software is copyright (c) 2019 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
